///////////////////////////////////////////////////////////////////////////////////////
// copy the files from this folder inside your \work folder
// don't forget to include grenade.wdl
// press the right mouse button to fire a grenade that explodes on impact
///////////////////////////////////////////////////////////////////////////////////////

function move_grenade();
function grenade_event();
function animated_explosion();
function barrel_explodes();

///////////////////////////////////////////////////////////////////////////////////////

string grenade_mdl = <grenade.mdl>;
string explosion_pcx = <explo+6.pcx>;
string barrel_pcx = <explo+9.pcx>;

///////////////////////////////////////////////////////////////////////////////////////

sound explosion_wav = <explosion.wav>;

///////////////////////////////////////////////////////////////////////////////////////

starter init_grenades()
{
	while (player == null) {wait (1);} // wait until the player is created
	while (1)
	{
		if (mouse_left == 1) // left mouse button (LMB) is pressed
		{
			ent_create (grenade_mdl, player.x, move_grenade);
			while (mouse_left == 1) {wait (1);} // wait until the LMB is released
		}
		sleep (0.1);
	}
}

function move_grenade()
{
	my.passable = on;
	my.pan = camera.pan;
	my.tilt = camera.tilt;
	my.enable_entity = on;
	my.enable_impact = on;
	my.enable_block = on;
	my.event = grenade_event;
	while (my != null)
	{
		if (vec_dist (my.x, player.x) > 50) {my.passable = off;}
		my.skill1 = 50 * time; // movement speed
		my.skill2 = 0; // speed on y
		if (my.skill40 < 100) // covered at least 100 quants?
		{
			my.skill3 = 0; // if not, don't apply gravity yet
		}
		else // moved away from the player
		{
			my.skill3 = -5 * (my.skill40 / 100) * time;
		}
		move_mode = ignore_you + ignore_passable;
		my.skill30 = ent_move (my.skill1, nullvector); // get the distance that was covered this frame in skill30
		my.skill40 += my.skill30; // store the distance covered so far in skill40
		wait (1);
	}
}

function grenade_event()
{
	wait (1);
	vec_set (temp, my.pos);
	temp.z += 10; // create the explosion sprite 10 quants above the ground
	ent_create(explosion_pcx, temp, animated_explosion); 
	ent_remove (me); 
}

function animated_explosion()
{
	wait (1);
	my.passable = on;
	my.flare = on;
	my.ambient = 100;
	ent_playsound (my, explosion_wav, 500);
	while (my.frame < 7)
	{
		my.frame += 1 * time;
		my.scale_x += 2 * time;
		my.scale_y = my.scale_x;
		my.scale_z = my.scale_x;
		player.roll = 2 - random(4); // shake the player a bit
		wait (1);
	}
	player.roll = 0; // restore player's roll angle
	my.invisible = on;
	temp.pan = 360; 
	temp.tilt = 180; 
	temp.z = 400; // hurt any entity that is sensitive to scanning on a range of 400 quants 
	scan_entity (my.x, temp); 
	sleep (2); // keep the explosion sound playing
	ent_remove (me); // remove the explosion sprite
}

action barrel 
{ 
	my.enable_scan = on; 
	my.event = barrel_explodes; 
} 

function barrel_explodes() 
{ 
	my.event = null; // don't trigger the event several times for the same barrel
	wait (1 + random(20)); // wait up to 20 frames
	ent_morph (my, barrel_pcx); 
	my.flare = on;
	my.ambient = 100;
	ent_playsound (my, explosion_wav, 200);
	while (my.frame < 10) 
	{ 
		my.frame += 1 * time; 
		wait (1); 
	} 
	my.invisible = on;
	temp.pan = 360; 
	temp.tilt = 180; 
	temp.z = 150; // hurt any entity that is sensitive to scanning on a range of 150 quants 
	scan_entity (my.x, temp); 
	sleep (2); // wait until the explosion sound is finished
	ent_remove (me);
}
